# 12 Segment Red/Green LED BAR
# Setup, test and demo
# Tony Goodhew - 29th April 2020

# Pin allocations
# R&G Anodes   Low  Med  High
# LED-Bargraph 1/14 6/9  7/8   either pin
#              D2   D3   D4    Use 330 Ohm resistors

# Cathodes    0    1    2    3
# Bargraph    2    3    4    5
# RED LEDs    A1   A2   A3   A4
# Bargraph    13   12   11   10
# GREEN LEDs  D13  D12  D11  D10

# 10K Ohm Potentiometer:
# Left to GND, Centre to A5 and Right to +3.3 Volts

import board
from analogio import AnalogIn
import gc
import time
from digitalio import DigitalInOut, Direction
gc.collect() # make some room
an = [0,0,0,0,1,1,1,1,2,2,2,2]
cd = [0,1,2,3,0,1,2,3,0,1,2,3]

# Set up 10 K Ohm pot
pot_in = AnalogIn(board.A5)

# Set up anodes
anodes = []
for p in [board.D2, board.D3, board.D4]:
    anode = DigitalInOut(p)
    anode.direction = Direction.OUTPUT
    anodes.append(anode)
# anodes OFF
for i in range(3):
    anodes[i].value = 0 # OFF

# Set up cathodes
REDcathodes = []
for p in [board.A1, board.A2, board.A3, board.A4]:
    REDcathode = DigitalInOut(p)
    REDcathode.direction = Direction.OUTPUT
    REDcathodes.append(REDcathode)
for i in range(4):
    REDcathodes[i].value = 1 # OFF

GREENcathodes = []
for p in [board.D13, board.D12, board.D11, board.D10]:
    GREENcathode = DigitalInOut(p)
    GREENcathode.direction = Direction.OUTPUT
    GREENcathodes.append(GREENcathode)
for i in range(4):
    GREENcathodes[i].value = 1 # OFF

# Test segments
wait = 0.15 # delay time
print("Green single LEDs")
for a in range(3):
    anodes[a].value = 1 # ON
    for c in range(4):
        GREENcathodes[c].value = 0  # ON
        time.sleep(wait)
        GREENcathodes[c].value = 1  # OFF
    anodes[a].value = 0 # OFF
print("Red single LEDs")
for a in range(3):
    anodes[a].value = 1 # ON
    for c in range(4):
        REDcathodes[c].value = 0 # ON
        time.sleep(wait)
        REDcathodes[c].value = 1 # OFF
    anodes[a].value = 0 # OFF
print("Orange single LEDs")
for a in range(3):
    anodes[a].value = 1 # ON
    for c in range(4):
        for i in range (wait * 15000):
            REDcathodes[c].value = 0   # ON
            GREENcathodes[c].value = 0 # ON = ORANGE
            REDcathodes[c].value = 1   #OFF
            GREENcathodes[c].value = 1 # OFF
    anodes[a].value = 0 #OFF

# TriColour
print("Green-Orange-Red Sections")
for a in range(3):
    anodes[a].value = 1 # ON
    for c in range(4):
        for i in range (wait * 15000):
            if a == 1 or a == 2:
                REDcathodes[c].value = 0   # ON
            if a == 0 or a == 1:
                GREENcathodes[c].value = 0 # ON = ORANGE
            REDcathodes[c].value = 1   #OFF
            GREENcathodes[c].value = 1 # OFF
    anodes[a].value = 0 #OFF

print("Twist Potentiometer knob - full range")
# RED LEDs
count = 0
while count < 90:
    p = int(12 * pot_in.value / 65300)
    if p > 0:
        p = p - 1
        anodes[an[p]].value = 1
        REDcathodes[cd[p]].value = 0
        time.sleep(0.05)
        anodes[an[p]].value = 0
        REDcathodes[cd[p]].value = 1
        count = count + 1
# GREEN LEDs
count = 0
while count < 90:
    p = int(12 * pot_in.value / 65300)
    if p > 0:
        p = p - 1
        anodes[an[p]].value = 1
        GREENcathodes[cd[p]].value = 0
        time.sleep(0.05)
        anodes[an[p]].value = 0
        GREENcathodes[cd[p]].value = 1
        count = count + 1

# ORANGE LEDs
count = 0
while count < 90:
    p = int(12 * pot_in.value / 65300)
    if p > 0:
        p = p - 1
        anodes[an[p]].value = 1
        GREENcathodes[cd[p]].value = 0
        REDcathodes[cd[p]].value = 0
        time.sleep(0.05)
        anodes[an[p]].value = 0
        GREENcathodes[cd[p]].value = 1
        REDcathodes[cd[p]].value = 1
        count = count + 1

# 3 colours LEDs
count = 0
while count < 90:
    p = int(12 * pot_in.value / 65300)
    if p > 0:
        p = p - 1
        anodes[an[p]].value = 1
        if an[p] == 0 or an[p] == 1:
            GREENcathodes[cd[p]].value = 0
        if an[p] == 1 or an[p] == 2:
            REDcathodes[cd[p]].value = 0
        time.sleep(0.05)
        anodes[an[p]].value = 0
        GREENcathodes[cd[p]].value = 1
        REDcathodes[cd[p]].value = 1
        count = count + 1

# Red/Green Bar filled from left end
print("Start")
count = 0
red = 1  # Initial colour Orange
green = 1
maxcount = 18000
limit1 = int(maxcount / 3)
limit2 = int(2 * maxcount / 3)
while count < maxcount:
    if count == limit1: # switch colours - Green
        green = 1
        red = 0
    if count == limit2: # Switch colours - Red
        green = 0
        red = 1
    p = int(12 * pot_in.value / 65300) # Read pot
    if p > 0:
        maxx = p
        for j in range(10):
            for x in range (maxx):
                anodes[an[x]].value = 1
                if green == 1:
                    GREENcathodes[cd[x]].value = 0
                if red == 1:
                    REDcathodes[cd[x]].value = 0
                time.sleep(0.002)
                anodes[an[x]].value = 0
                REDcathodes[cd[x]].value = 1
                GREENcathodes[cd[x]].value = 1
    count = count + 1

print("############## Done ###############"  )